var util = require('util');
var requireR = require('require-r');

var debugList = {};
var debugAll;
initConfig();

var prevTime;
var prevColor = 0;
var colors = [6, 2, 3, 4, 5, 1];

module.exports = function (tag) {
  if (!debugAll && !debugList[tag]) {
    return doNothing;
  }

  var color = colors[prevColor++ % colors.length];

  return function () {
    var curr = +new Date();
    var ms = curr - (prevTime || curr);
    prevTime = curr;

    var args = Array.prototype.slice.call(arguments);
    args.unshift('\u001b[9' + color + 'm' + tag + ' +' + ms + 'ms\x1B[39m');
    console.log.apply(console, args);
  }
};

function doNothing () {
}

function initConfig () {
  var config;
  try {
    config = requireR('debug.json');
  } catch (e) {
    config = { debug: true };
  }

  if (typeof config.debug == 'boolean') {
    debugAll = config.debug;
    console.log("JS-DEBUG: " + (debugAll ? 'ALL' : 'NONE'));
  } else if (util.isArray(config.debug)) {
    config.debug.forEach(function (value) {
      initDebugList(config.tasks[value]);
    });
    logDebugList();
  }

  function initDebugList (tasks) {
    tasks.forEach(function (value) {
      debugList[value] = true;
    });
  }

  function logDebugList () {
    var debugListArr = [];
    Object.keys(debugList).forEach(function (value) {
      debugListArr.push(value);
    });
    console.log("JS-DEBUG: " + debugListArr.toString());
  }
}

